@@ -29,14 +29,13 @@ pip install bussilab
 Required packages will be downloaded and installed automatically in the virtual
 environment.
 
-
 _conda_.
-If you manage your dependencies with conda you might prefer to install [required
-packages first](https://www.anaconda.com/using-pip-in-a-conda-environment/):
+If you manage your dependencies with conda, use:
 ```bash
-_conda_install_
-pip install --no-deps bussilab
+conda install -c conda-forge -c bussilab py-bussilab
 ```
+Required packages will be downloaded and installed automatically in the active
+conda environment.
 
 _macports_.
 If you manage your dependencies with macports you might prefer to install required packages
@@ -142,6 +141,7 @@ and the `bin` directory to `PATH`:
 export PATH="/path/to/bussilab/bin:$PATH"
 export PYTHONPATH="/path/to/bussilab:$PYTHONPATH"
 ```
+This is convenient if you want to use the development version of this package.
 
 [^pure_python]: This might change in the future.
 
@@ -150,7 +150,7 @@ export PYTHONPATH="/path/to/bussilab:$PYTHONPATH"
 You can run the tests using `pytest`:
 ```bash
 pip install pytest
-py.test
+pytest
 ```
 
 All tests should succeed.
@@ -161,7 +161,16 @@ You can rerun all the jupyter examples from the command line:
 ```bash
 cd examples
 pip install jupyter jupyter_contrib_nbextensions matplotlib
-bash rerun.sh
+./rerun.sh
+```
+
+### Rendering jupyter examples as html from the command line
+
+You can render all the jupyter examples as html from the command line:
+```bash
+cd examples
+pip install jupyter nbconvert
+./render.sh
 ```
 
 ### Building documentation
@@ -211,26 +220,32 @@ _required_ = [
     'numba',
     'numpy',
     'scipy',
-    'slackclient',
+    'slackclient>2',
     'pyyaml'
 ]
 
-_macports_py_ = "3.7"
+_macports_py_ = "3.8"
+
+def _process_macports(macports: _List[str]) -> _List[str]:
+    import re
+    l = [ 'py-pip' , 'py-setuptools' ]
+    for d in _required_:
+      d=re.sub(">.*$","",d) # remove versions
+      d=re.sub("^pyyaml$","yaml",d) # fix yaml
+      l.append("py-" + d)
+    return l
+
+_macports_required_ = _process_macports(_required_)
 
 # process documentation in order to update variables in a single point.
 def _process_doc(doc: str) -> str:
     import re
-    _conda_install_ = "conda install "+" ".join(_required_)
-    _macports_py_not_dot = _macports_py_[0] + _macports_py_[2]
+    _macports_py_not_dot = "py" + _macports_py_[0] + _macports_py_[2]
     _macports_install_ = (
         "sudo port install "
-        + "py" + _macports_py_not_dot + "-pip "
-        + "py" + _macports_py_not_dot + "-setuptools "
-        +" ".join(["py" + _macports_py_not_dot + "-" + mod for mod in _required_])
+        + re.sub("py-", _macports_py_not_dot + '-', ' '.join(_macports_required_))
     )
-    _macports_install_ = re.sub('-pyyaml', '-yaml', _macports_install_)
     doc = re.sub("__version__", __version__, doc)
-    doc = re.sub("_conda_install_", _conda_install_, doc)
     doc = re.sub("_macports_install_", _macports_install_, doc)
     doc = re.sub("_macports_py_", _macports_py_, doc)
     return doc
@@ -317,7 +332,7 @@ def describe_submodule(module: str) -> str:
        str
            The docstring of the module. If the docstring is not present,
            returns an empty string. If an empy string is passed as `module`,
-           the docstring ot the main package is returned.
+           the docstring of the main package is returned.
 
        Raises
        ------
